package com.tildemh.debbuggtk;

import org.gnu.gtk.*;

/**
 * <p>Details of a column in the listingReport
 *
 * <p>This is released under the terms of the GNU Lesser General Public License
 * (LGPL). See the COPYING file for details.
 *
 * @version $Id: ListingColumn.java,v 1.1 2003/12/11 12:53:40 mh Exp $
 * @author &copy; Mark Howard &lt;mh@debian.org&gt; 2002
 */
public class ListingColumn{
	
	private String title;
	private String example;
	private boolean visible;
	private TreeViewColumn column;

	public ListingColumn( String title, String example, boolean visible, TreeViewColumn column ){
		this.title = title;
		this.example = example;
		this.visible = visible;
		this.column = column;
	}

	public String getTitle(){
		return title;
	}

	public String getExample(){
		return example;
	}
	public boolean getVisible(){
		return visible;
	}
	public TreeViewColumn getColumn(){
		return column;
	}

	public void setVisible( boolean visible ){
		this.visible = visible;
	}
}
